@@ -31,14 +31,14 @@
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <klibloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kuniqueapplication.h>
 #include <kiconloader.h>
-#include <kactionclasses.h>
-#include <klocale.h>
+#include <tdeactionclasses.h>
+#include <tdelocale.h>
 #include <kprogress.h>
-#include <kconfigdialog.h>
-#include <kaccel.h>
+#include <tdeconfigdialog.h>
+#include <tdeaccel.h>
 
 // application specific includes
 #include "smb4k.h"
@@ -46,12 +46,12 @@
 #include "dialogs/smb4kbookmarkeditor.h"
 #include "core/smb4ksettings.h"
 #include "core/smb4kcore.h"
-#include "core/smb4kglobal.h"
+#include "core/smb4tdeglobal.h"
 #include "core/smb4kbookmark.h"
 #include "core/smb4kshare.h"
 #include "core/smb4kdefs.h"
 
-using namespace Smb4KGlobal;
+using namespace Smb4TDEGlobal;
 
 
 Smb4KApp::Smb4KApp( TQWidget *parent, const char *name )
@@ -124,8 +124,8 @@ Smb4KApp::Smb4KApp( TQWidget *parent, const char *name )
   }
 
   // Connections
-  connect( actionCollection(),           TQT_SIGNAL( actionHighlighted( KAction * ) ),
-           this,                         TQT_SLOT( slotActionHighlighted( KAction * ) ) );
+  connect( actionCollection(),           TQT_SIGNAL( actionHighlighted( TDEAction * ) ),
+           this,                         TQT_SLOT( slotActionHighlighted( TDEAction * ) ) );
 
   connect( Smb4KCore::self(),            TQT_SIGNAL( runStateChanged() ),
            this,                         TQT_SLOT( slotRunStateChanged() ) );
@@ -153,14 +153,14 @@ void Smb4KApp::setupActions()
   setStandardToolBarMenuEnabled( true );
   createStandardStatusBarAction();
 
-  KActionMenu *view_modes  = new KActionMenu( i18n( "Shares Vie&w" ), "view_choose",
+  TDEActionMenu *view_modes  = new TDEActionMenu( i18n( "Shares Vie&w" ), "view_choose",
                              actionCollection(), "view_modes_menu" );
 
-  KRadioAction *icon_view  = new KRadioAction( i18n( "&Icon View" ), "view_icon", CTRL+Key_I,
+  TDERadioAction *icon_view  = new TDERadioAction( i18n( "&Icon View" ), "view_icon", CTRL+Key_I,
                              TQT_TQOBJECT(this), TQT_SLOT( slotChangeSharesView() ), actionCollection(), "icon_view_action" );
   icon_view->setExclusiveGroup( "SharesViewActions" );
 
-  KRadioAction *list_view  = new KRadioAction( i18n( "List Vie&w" ), "view_detailed", CTRL+Key_W,
+  TDERadioAction *list_view  = new TDERadioAction( i18n( "List Vie&w" ), "view_detailed", CTRL+Key_W,
                              TQT_TQOBJECT(this), TQT_SLOT( slotChangeSharesView() ), actionCollection(), "list_view_action" );
   list_view->setExclusiveGroup( "SharesViewActions" );
 
@@ -252,7 +252,7 @@ void Smb4KApp::setupView()
 
     if ( m_shares_part )
     {
-      KDockWidget *main = createDockWidget( "SharesView", SmallIcon( "hdd_mount" ), 0L );
+      KDockWidget *main = createDockWidget( "SharesView", SmallIcon( "drive-harddisk-mounted" ), 0L );
       main->setWidget( m_shares_part->widget() );
       main->setDockSite( KDockWidget::DockCorner );
       main->setEnableDocking( KDockWidget::DockNone );
@@ -268,7 +268,7 @@ void Smb4KApp::setupView()
   {
     KMessageBox::error( 0, "<qt>"+KLibLoader::self()->lastErrorMessage()+"</qt>" );
 
-    KApplication::exit( 0 );
+    TDEApplication::exit( 0 );
 
     return;
   }
@@ -297,7 +297,7 @@ void Smb4KApp::setupView()
   {
     KMessageBox::error( 0, "<qt>"+KLibLoader::self()->lastErrorMessage()+"</qt>" );
 
-    KApplication::exit( 0 );
+    TDEApplication::exit( 0 );
 
     return;
   }
@@ -313,7 +313,7 @@ void Smb4KApp::setupView()
 
     if ( m_search_part )
     {
-      KDockWidget *search = createDockWidget( "SearchDialog", SmallIcon( "find" ), 0L, i18n( "Search Dialog" ) );
+      KDockWidget *search = createDockWidget( "SearchDialog", SmallIcon( "edit-find" ), 0L, i18n( "Search Dialog" ) );
       search->setWidget( m_search_part->widget() );
 
       KDockWidget *network = manager()->getDockWidgetFromName( "NetworkBrowser" );
@@ -336,7 +336,7 @@ void Smb4KApp::setupView()
   {
     KMessageBox::error( 0, "<qt>"+KLibLoader::self()->lastErrorMessage()+"</qt>" );
 
-    KApplication::exit( 0 );
+    TDEApplication::exit( 0 );
 
     return;
   }
@@ -407,7 +407,7 @@ void Smb4KApp::changeSharesView()
 
     if ( m_shares_part )
     {
-      KDockWidget *main = createDockWidget( "SharesView", SmallIcon( "hdd_mount" ), this );
+      KDockWidget *main = createDockWidget( "SharesView", SmallIcon( "drive-harddisk-mounted" ), this );
       main->setWidget( m_shares_part->widget() );
       main->setDockSite( KDockWidget::DockCorner );
       main->setEnableDocking( KDockWidget::DockNone );
@@ -421,7 +421,7 @@ void Smb4KApp::changeSharesView()
   {
     KMessageBox::error( 0, "<qt>"+KLibLoader::self()->lastErrorMessage()+"</qt>" );
 
-    KApplication::exit( 0 );
+    TDEApplication::exit( 0 );
 
     return;
   }
@@ -500,7 +500,7 @@ void Smb4KApp::slotQuit()
     m_system_tray->embed( false );
   }
 
-  KApplication::exit( 0 );
+  TDEApplication::exit( 0 );
 }
 
 
@@ -525,7 +525,7 @@ void Smb4KApp::slotChangeSharesView()
     return;
   }
 
-  KRadioAction *shares_view_action = static_cast<KRadioAction *>( m_action );
+  TDERadioAction *shares_view_action = static_cast<TDERadioAction *>( m_action );
 
   // Set the check mark for the action:
   if ( !shares_view_action->isChecked() )
@@ -561,17 +561,17 @@ void Smb4KApp::slotConfigDialog()
 {
   // If the config dialog is already created and cached,
   // we do not create a new one but show the old instead:
-  if ( KConfigDialog::showDialog( "ConfigDialog" ) )
+  if ( TDEConfigDialog::showDialog( "ConfigDialog" ) )
   {
     return;
   }
 
   // Load the factory of the config dialog:
-  KLibFactory *config_factory = KLibLoader::self()->factory( "libsmb4kconfigdialog" );
+  KLibFactory *config_factory = KLibLoader::self()->factory( "libsmb4tdeconfigdialog" );
 
   if ( config_factory )
   {
-    KConfigDialog *dlg = static_cast<KConfigDialog *>( TQT_TQWIDGET(config_factory->create( TQT_TQOBJECT(this), "ConfigDialog", "KConfigDialog" )) );
+    TDEConfigDialog *dlg = static_cast<TDEConfigDialog *>( TQT_TQWIDGET(config_factory->create( TQT_TQOBJECT(this), "ConfigDialog", "TDEConfigDialog" )) );
 
     if ( dlg )
     {
@@ -813,10 +813,10 @@ void Smb4KApp::slotSetupBookmarksMenu()
   {
     unplugActionList( "bookmark_actions" );
 
-    TQPtrList<KAction> bookmark_actions;
+    TQPtrList<TDEAction> bookmark_actions;
 
     // Create the "Edit Bookmarks" action:
-    bookmark_actions.append( new KAction( i18n( "&Edit Bookmarks" ), "bookmark", CTRL+Key_E,
+    bookmark_actions.append( new TDEAction( i18n( "&Edit Bookmarks" ), "bookmark", CTRL+Key_E,
                              TQT_TQOBJECT(this), TQT_SLOT( slotBookmarkEditor() ), actionCollection(),
                              "edit_bookmarks_action" ) );
 
@@ -837,7 +837,7 @@ void Smb4KApp::slotSetupBookmarksMenu()
       }
     }
 
-    bookmark_actions.append( new KActionSeparator() );
+    bookmark_actions.append( new TDEActionSeparator() );
 
     plugActionList( "bookmark_actions", bookmark_actions );
   }
@@ -848,9 +848,9 @@ void Smb4KApp::slotSetupBookmarksMenu()
   // Get the bookmark action list and delete all entries. We could
   // also try to keep those actions that are not obsolete, but I think
   // this is the cleanest way.
-  KActionPtrList list = actionCollection()->actions( "Bookmarks" );
+  TDEActionPtrList list = actionCollection()->actions( "Bookmarks" );
 
-  for ( KActionPtrList::Iterator it = list.begin(); it != list.end(); ++it )
+  for ( TDEActionPtrList::Iterator it = list.begin(); it != list.end(); ++it )
   {
     actionCollection()->remove( *it );
   }
@@ -882,11 +882,11 @@ void Smb4KApp::slotSetupBookmarksMenu()
     display_strings.sort();
 
     // Create the bookmark list and plug it into the menu:
-    TQPtrList<KAction> bookmark_list;
+    TQPtrList<TDEAction> bookmark_list;
 
     for ( TQStringList::ConstIterator it = display_strings.begin(); it != display_strings.end(); ++it )
     {
-      KAction *a = new KAction( *it, "folder", KShortcut::null(), 0, 0, actionCollection(), *it );
+      TDEAction *a = new TDEAction( *it, "folder", TDEShortcut::null(), 0, 0, actionCollection(), *it );
       a->setGroup( "Bookmarks" );
       connect( a, TQT_SIGNAL( activated() ), TQT_TQOBJECT(this), TQT_SLOT( slotBookmarkActivated() ) );
       bookmark_list.append( a );
@@ -927,13 +927,13 @@ void Smb4KApp::slotBookmarkActivated()
 
 void Smb4KApp::slotShareListUpdated()
 {
-  KActionPtrList list = actionCollection()->actions( "Bookmarks" );
+  TDEActionPtrList list = actionCollection()->actions( "Bookmarks" );
 
   if ( !list.isEmpty() )
   {
     TQString name;
 
-    for ( KActionPtrList::ConstIterator it = list.begin(); it != list.end(); ++it )
+    for ( TDEActionPtrList::ConstIterator it = list.begin(); it != list.end(); ++it )
     {
       if ( !(*it)->plainText().startsWith( "//" ) )
       {
@@ -970,7 +970,7 @@ void Smb4KApp::slotShareListUpdated()
 }
 
 
-void Smb4KApp::slotActionHighlighted( KAction *action )
+void Smb4KApp::slotActionHighlighted( TDEAction *action )
 {
   m_action = action;
 }
